@@ -22,7 +22,7 @@
 
 char offset127=127; 
 char offset0xD5=(char)0xD5; 
-char offset0=0;
+char offset0[4] = {0x00, 0x00, 0x00, 0x00};
 
 /* 
  * IMPORTANT : some compiler don't support the tagged-field syntax. Those
@@ -39,8 +39,8 @@ char offset0=0;
 #define PATTERN_LENGTH(val)	.pattern_length=(val)
 #define NORMAL_BITRATE(val)	.normal_bitrate=(val)
 #define MIME_TYPE(val)		.mime_type=(val)
+#define CHANNELS(val)		.channels=(val)
 #define FMTP(val)		.FMTP=(val)
-
 #elif defined(__GNUC__)
 // GCC's legacy tagged syntax (even old versions have it)
 #define TYPE(val)		type: (val)
@@ -50,8 +50,8 @@ char offset0=0;
 #define PATTERN_LENGTH(val)	pattern_length: (val)
 #define NORMAL_BITRATE(val)	normal_bitrate: (val)
 #define MIME_TYPE(val)		mime_type: (val)
+#define CHANNELS(val)		channels: (val)
 #define FMTP(val)		FMTP: (val)
-
 #else
 // No tagged syntax supported
 #define TYPE(val)		(val)
@@ -61,6 +61,7 @@ char offset0=0;
 #define PATTERN_LENGTH(val)	(val)
 #define NORMAL_BITRATE(val)	(val)
 #define MIME_TYPE(val)		(val)
+#define CHANNELS(val)		(val)
 #define FMTP(val)		(val)
 
 #endif
@@ -72,7 +73,8 @@ PayloadType payload_type_pcmu8000={
 	ZERO_PATTERN( &offset127),
 	PATTERN_LENGTH( 1),
 	NORMAL_BITRATE( 64000),
-	MIME_TYPE ("PCMU")
+	MIME_TYPE ("PCMU"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_pcma8000={
@@ -82,17 +84,41 @@ PayloadType payload_type_pcma8000={
 	ZERO_PATTERN( &offset0xD5),
 	PATTERN_LENGTH( 1),
 	NORMAL_BITRATE( 64000),
-	MIME_TYPE ("PCMA")
+	MIME_TYPE ("PCMA"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_pcm8000={
 	TYPE( PAYLOAD_AUDIO_CONTINUOUS),
 	CLOCK_RATE(8000),
 	BITS_PER_SAMPLE(16),
-	ZERO_PATTERN( &offset0),
+	ZERO_PATTERN( offset0),
 	PATTERN_LENGTH(1),
 	NORMAL_BITRATE( 128000),
-	MIME_TYPE ("PCM")
+	MIME_TYPE ("PCM"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_l16_mono={
+	TYPE( PAYLOAD_AUDIO_CONTINUOUS),
+	CLOCK_RATE(44100),
+	BITS_PER_SAMPLE(16),
+	ZERO_PATTERN( offset0 ),
+	PATTERN_LENGTH(2),
+	NORMAL_BITRATE(705600),				/* (44100 x 16bits per frame x 1 channel) */
+	MIME_TYPE ("L16"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_l16_stereo={
+	TYPE( PAYLOAD_AUDIO_CONTINUOUS),
+	CLOCK_RATE(44100),
+	BITS_PER_SAMPLE(32),				/* 16bits x 2 channels */
+	ZERO_PATTERN( offset0 ),
+	PATTERN_LENGTH(4),
+	NORMAL_BITRATE(1411200),			/* (44100 x 16bits per frame x 2 channels) */
+	MIME_TYPE ("L16"),
+	CHANNELS(2)
 };
 
 PayloadType payload_type_lpc1016={
@@ -102,7 +128,8 @@ PayloadType payload_type_lpc1016={
 	ZERO_PATTERN( NULL),
 	PATTERN_LENGTH( 0),
 	NORMAL_BITRATE( 2400),
-	MIME_TYPE ("1016")
+	MIME_TYPE ("1016"),
+	CHANNELS(1)
 };
 
 
@@ -114,7 +141,20 @@ PayloadType payload_type_gsm=
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH( 0),
 	NORMAL_BITRATE( 13500),
-	MIME_TYPE ("GSM")
+	MIME_TYPE ("GSM"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_lpc=
+{
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 5600),		/* 20ms / 14 octets per frame */
+	MIME_TYPE ("LPC"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_g7231=
@@ -125,7 +165,8 @@ PayloadType payload_type_g7231=
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH( 0),
 	NORMAL_BITRATE( 6300),
-	MIME_TYPE ("G723")
+	MIME_TYPE ("G723"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_g729={
@@ -135,7 +176,63 @@ PayloadType payload_type_g729={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH( 0),
 	NORMAL_BITRATE( 8000),
-	MIME_TYPE ("G729")
+	MIME_TYPE ("G729"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_g7221={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(16000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 24000),
+	MIME_TYPE ("G7221"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_g726_40={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 8000),
+	MIME_TYPE ("G726-40"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_g726_32={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 8000),
+	MIME_TYPE ("G726-32"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_g726_24={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 8000),
+	MIME_TYPE ("G726-24"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_g726_16={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE( 0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH( 0),
+	NORMAL_BITRATE( 8000),
+	MIME_TYPE ("G726-16"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_mpv=
@@ -146,7 +243,8 @@ PayloadType payload_type_mpv=
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE( 256000),
-	MIME_TYPE ("MPV")
+	MIME_TYPE ("MPV"),
+	CHANNELS(0)
 };
 
 
@@ -157,7 +255,8 @@ PayloadType payload_type_h261={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(0),
-	MIME_TYPE ("H261")
+	MIME_TYPE ("H261"),
+	CHANNELS(0)
 };
 
 PayloadType payload_type_h263={
@@ -167,7 +266,8 @@ PayloadType payload_type_h263={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(256000),
-	MIME_TYPE ("H263")
+	MIME_TYPE ("H263"),
+	CHANNELS(0)
 };
 
 PayloadType payload_type_truespeech=
@@ -178,7 +278,8 @@ PayloadType payload_type_truespeech=
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH( 0),
 	NORMAL_BITRATE(8536),
-	MIME_TYPE ("TSP0")
+	MIME_TYPE ("TSP0"),
+	CHANNELS(0)
 };
 
 
@@ -199,8 +300,12 @@ void av_profile_init(RtpProfile *profile)
 	rtp_profile_set_payload(profile,0,&payload_type_pcmu8000);
 	rtp_profile_set_payload(profile,1,&payload_type_lpc1016);
 	rtp_profile_set_payload(profile,3,&payload_type_gsm);
+	rtp_profile_set_payload(profile,7,&payload_type_lpc);
 	rtp_profile_set_payload(profile,4,&payload_type_g7231);
 	rtp_profile_set_payload(profile,8,&payload_type_pcma8000);
+	rtp_profile_set_payload(profile,9,&payload_type_g722);
+	rtp_profile_set_payload(profile,10,&payload_type_l16_stereo);
+	rtp_profile_set_payload(profile,11,&payload_type_l16_mono);
 	rtp_profile_set_payload(profile,18,&payload_type_g729);
 	rtp_profile_set_payload(profile,31,&payload_type_h261);
 	rtp_profile_set_payload(profile,32,&payload_type_mpv);
@@ -209,43 +314,58 @@ void av_profile_init(RtpProfile *profile)
 	
 /* these are extra payload types that can be used dynamically */
 PayloadType payload_type_lpc1015={
-    TYPE( PAYLOAD_AUDIO_PACKETIZED),
-    CLOCK_RATE(8000),
-    BITS_PER_SAMPLE(0),
-    ZERO_PATTERN(NULL),
-    PATTERN_LENGTH(0),
-    NORMAL_BITRATE(2400),
-    MIME_TYPE ("1015")
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(2400),
+	MIME_TYPE ("1015"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_speex_nb={
-    TYPE( PAYLOAD_AUDIO_PACKETIZED),
-    CLOCK_RATE(8000),
-    BITS_PER_SAMPLE(0),
-    ZERO_PATTERN(NULL),
-    PATTERN_LENGTH(0),
-    NORMAL_BITRATE(8000),   /*not true: 8000 is the minimum*/
-    MIME_TYPE ("speex")
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(8000),   /*not true: 8000 is the minimum*/
+	MIME_TYPE ("speex"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_speex_wb={
-    TYPE( PAYLOAD_AUDIO_PACKETIZED),
-    CLOCK_RATE(16000),
-    BITS_PER_SAMPLE(0),
-    ZERO_PATTERN(NULL),
-    PATTERN_LENGTH(0),
-    NORMAL_BITRATE(28000),
-    MIME_TYPE ("speex")
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(16000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(28000),
+	MIME_TYPE ("speex"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_speex_uwb={
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(32000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(28000),
+	MIME_TYPE ("speex"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_ilbc={
-	 TYPE( PAYLOAD_AUDIO_PACKETIZED),
-    CLOCK_RATE(8000),
-    BITS_PER_SAMPLE(0),
-    ZERO_PATTERN(NULL),
-    PATTERN_LENGTH(0),
-    NORMAL_BITRATE(13300), /* the minimum, with 30ms frames */ 
-    MIME_TYPE ("iLBC"),
+	TYPE( PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(13300), /* the minimum, with 30ms frames */ 
+	MIME_TYPE ("iLBC"),
+	CHANNELS(1),
 };
 
 PayloadType payload_type_amr={
@@ -254,8 +374,9 @@ PayloadType payload_type_amr={
 	BITS_PER_SAMPLE(0),
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
-	NORMAL_BITRATE(0),
-	MIME_TYPE ("AMR")
+	NORMAL_BITRATE(12200),
+	MIME_TYPE ("AMR"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_amrwb={
@@ -265,7 +386,8 @@ PayloadType payload_type_amrwb={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(0),
-	MIME_TYPE ("AMR-WB")
+	MIME_TYPE ("AMR-WB"),
+	CHANNELS(1)
 };
 
 PayloadType payload_type_mp4v={
@@ -275,10 +397,33 @@ PayloadType payload_type_mp4v={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(0),
-	MIME_TYPE ("MP4V-ES")
+	MIME_TYPE ("MP4V-ES"),
+	CHANNELS(0)
 };
-    
-    
+
+
+PayloadType payload_type_evrc0={
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(0),
+	MIME_TYPE ("EVRC0"),
+	CHANNELS(1)
+};
+
+PayloadType payload_type_evrcb0={
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(0),
+	MIME_TYPE ("EVRCB0"),
+	CHANNELS(1)
+};
+ 
 PayloadType payload_type_h263_1998={
 	TYPE( PAYLOAD_VIDEO),
 	CLOCK_RATE(90000),
@@ -286,7 +431,8 @@ PayloadType payload_type_h263_1998={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(256000),
-	MIME_TYPE ("H263-1998")
+	MIME_TYPE ("H263-1998"),
+	CHANNELS(0)
 };
 
 PayloadType payload_type_h263_2000={
@@ -296,7 +442,8 @@ PayloadType payload_type_h263_2000={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(0),
-	MIME_TYPE ("H263-2000")
+	MIME_TYPE ("H263-2000"),
+	CHANNELS(0)
 };
 
 PayloadType payload_type_theora={
@@ -306,6 +453,77 @@ PayloadType payload_type_theora={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(256000),
-	MIME_TYPE ("theora")
+	MIME_TYPE ("theora"),
+	CHANNELS(0)
 };
 
+PayloadType payload_type_h264={
+	TYPE( PAYLOAD_VIDEO),
+	CLOCK_RATE(90000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(256000),
+	MIME_TYPE ("H264"),
+	CHANNELS(0)
+};
+
+PayloadType payload_type_x_snow={
+	TYPE( PAYLOAD_VIDEO),
+	CLOCK_RATE(90000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(256000),
+	MIME_TYPE ("x-snow"),
+	CHANNELS(0)
+};
+
+PayloadType payload_type_jpeg={
+	TYPE( PAYLOAD_VIDEO),
+	CLOCK_RATE(90000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(256000),
+	MIME_TYPE ("JPEG"),
+	CHANNELS(0)
+};
+
+
+PayloadType	payload_type_t140={
+	PAYLOAD_AUDIO_PACKETIZED, /*type */
+	1000,
+	0,
+	NULL,
+	0,
+	0,
+	"t140",
+	0,
+	0
+};
+
+PayloadType	payload_type_x_udpftp={
+	PAYLOAD_AUDIO_PACKETIZED, /*type */
+	1000,
+	0,
+	NULL,
+	0,
+	0,
+	"x-udpftp",
+	0,
+	0
+};
+
+PayloadType payload_type_g722={
+       TYPE( PAYLOAD_AUDIO_PACKETIZED),
+       CLOCK_RATE(8000),
+       BITS_PER_SAMPLE( 0),
+       ZERO_PATTERN(NULL),
+       PATTERN_LENGTH( 0),
+       NORMAL_BITRATE( 64000),
+       MIME_TYPE ("G722"),
+       CHANNELS(1)
+};
+
+
