@@ -21,22 +21,11 @@
 #include <ortp/sessionset.h>
 #include "scheduler.h"
 
-/**
- *session_set_init:
- *@ss:	 a SessionSet statically allocated.
- *
- *	Initializes a session set. It is unusefull to call this function on a session set object
- *	returned by session_set_new().
- *
-**/
-
 
 /**
- *session_set_new:
- *
  * Allocates and initialize a new empty session set.
  *
- *Returns: the session set.
+ * @return the empty session set.
 **/
 SessionSet * session_set_new()
 {
@@ -47,8 +36,6 @@ SessionSet * session_set_new()
 
 
 /**
- *session_set_destroy:
- *@set:	a SessionSet
  * Destroys a session set.
  *
 **/
@@ -58,11 +45,32 @@ void session_set_destroy(SessionSet *set)
 	ortp_free(set);
 }
 
+int count_power_items_simple(int v) 
+{
+    int c = 0,j;
+    for (j=0;j<32;j++){
+        if ( ((v)>>j) & 1){
+	    ++c;
+        }
+    }
+    return c;
+}
+
+int count_power_items_fast(int v) 
+{
+    int c = 0;
+    while(v) {
+        c += (v & 1);
+	v >>= 1;
+    }
+    return c;
+}
+
 int session_set_and(SessionSet *sched_set, int maxs, SessionSet *user_set, SessionSet *result_set)
 {
 	uint32_t *mask1,*mask2,*mask3;
 	int i=0;
-	int j,ret=0;
+	int ret=0;
 	mask1=(uint32_t*)(void*)&sched_set->rtpset;
 	mask2=(uint32_t*)(void*)&user_set->rtpset;
 	mask3=(uint32_t*)(void*)&result_set->rtpset;
@@ -70,13 +78,7 @@ int session_set_and(SessionSet *sched_set, int maxs, SessionSet *user_set, Sessi
 		*mask3=(*mask1) & (*mask2);	/* computes the AND between the two masks*/
 		/* and unset the sessions that have been found from the sched_set */
 		*mask1=(*mask1) & (~(*mask3));
-		if ((*mask3)!=0){
-			for (j=0;j<32;j++){
-				if ( ((*mask3)>>j) & 1){
-					ret++;
-				}
-			}
-		}
+		ret += count_power_items_fast(*mask3);
 		i+=32;
 		mask1++;
 		mask2++;
@@ -87,11 +89,6 @@ int session_set_and(SessionSet *sched_set, int maxs, SessionSet *user_set, Sessi
 }
 
 /**
- *session_set_select:
- *@recvs:		a set of rtp sessions to be watched for read events
- *@sends:		a set of rtp sessions to be watched for write events
- *@errors:		a set of rtp sessions to be watched for errors
- *
  *	This function performs similarly as libc select() function, but performs on #RtpSession 
  *	instead of file descriptors.
  *	session_set_select() suspends the calling process until some events arrive on one of the
@@ -108,7 +105,10 @@ int session_set_and(SessionSet *sched_set, int maxs, SessionSet *user_set, Sessi
  *	Sessions can be added to sets using session_set_set(), a session has to be tested to be 
  *	part of a set using session_set_is_set().
  *
- *Returns: the number of sessions on which the selected events happened.
+ * @param recvs a set of rtp sessions to be watched for read events
+ * @param sends a set of rtp sessions to be watched for write events
+ * @param errors a set of rtp sessions to be watched for errors
+ * @return: the number of sessions on which the selected events happened.
 **/
 int session_set_select(SessionSet *recvs, SessionSet *sends, SessionSet *errors)
 {
@@ -123,25 +123,26 @@ int session_set_select(SessionSet *recvs, SessionSet *sends, SessionSet *errors)
 		/* computes the SessionSet intersection (in the other words mask intersection) between
 		the mask given by the user and scheduler masks */
 		if (recvs!=NULL){
+			session_set_init(&temp);
 			bits=session_set_and(&sched->r_sessions,sched->all_max,recvs,&temp);
-			if (bits>0){
-				ret+=bits;
-				/* copy the result set in the given user set */
-				session_set_copy(recvs,&temp);
-			}
+			ret+=bits;
+			/* copy the result set in the given user set (might be empty) */
+			if (ret>0) session_set_copy(recvs,&temp);
 		}
 		if (sends!=NULL){
+			session_set_init(&temp);
 			bits=session_set_and(&sched->w_sessions,sched->all_max,sends,&temp);
-			if (bits>0){
-				ret+=bits;
-				/* copy the result set in the given user set */
+			ret+=bits;
+			if (ret>0){
+				/* copy the result set in the given user set (might be empty)*/
 				session_set_copy(sends,&temp);
 			}
 		}
 		if (errors!=NULL){
+			session_set_init(&temp);
 			bits=session_set_and(&sched->e_sessions,sched->all_max,errors,&temp);
-			if (bits>0){
-				ret+=bits;
+			ret+=bits;
+			if (ret>0){
 				/* copy the result set in the given user set */
 				session_set_copy(errors,&temp);
 			}
@@ -160,28 +161,59 @@ int session_set_select(SessionSet *recvs, SessionSet *sends, SessionSet *errors)
 	return -1;
 }
 
-/**
- *session_set_set:
- *@ss:		a set (#SessionSet object)
- *@rtpsession:	a rtp session
- *
- *	This macro adds rtp session @_session to set @_set.
-**/
+int session_set_timedselect(SessionSet *recvs, SessionSet *sends, SessionSet *errors,  struct timeval *timeout)
+{
+	int ret=0,bits;
+	int remainingTime; // duration in ms
+	SessionSet temp;
+	RtpScheduler *sched;
+	if (timeout==NULL)
+		return session_set_select(recvs, sends, errors);
+	sched=ortp_get_scheduler();
+	remainingTime = timeout->tv_usec/1000 + timeout->tv_sec*1000;
 
-/**
- *session_set_is_set:
- *@ss:		a set (#SessionSet object)
- *@rtpsession:	a rtp session
- *
- *	This macro tests if @_session is part of @_set. 1 is returned if true, 0 else.
-**/
+	/*lock the scheduler to not read the masks while they are being modified by the scheduler*/
+	rtp_scheduler_lock(sched);
 
-/**
- *session_set_clr:
- *@ss:	a set of sessions.
- *@rtpsession: a rtp session.
- *
- *	Removes the @_session from the _set.
- *
- *
-**/
+	do {
+		/* computes the SessionSet intersection (in the other words mask intersection) between
+		the mask given by the user and scheduler masks */
+		if (recvs!=NULL){
+			session_set_init(&temp);
+			bits=session_set_and(&sched->r_sessions,sched->all_max,recvs,&temp);
+			ret+=bits;
+			/* copy the result set in the given user set (might be empty) */
+			if (ret>0) session_set_copy(recvs,&temp);
+		}
+		if (sends!=NULL){
+			session_set_init(&temp);
+			bits=session_set_and(&sched->w_sessions,sched->all_max,sends,&temp);
+			ret+=bits;
+			if (ret>0){
+				/* copy the result set in the given user set (might be empty)*/
+				session_set_copy(sends,&temp);
+			}
+		}
+		if (errors!=NULL){
+			session_set_init(&temp);
+			bits=session_set_and(&sched->e_sessions,sched->all_max,errors,&temp);
+			ret+=bits;
+			if (ret>0){
+				/* copy the result set in the given user set */
+				session_set_copy(errors,&temp);
+			}
+		}
+		if (ret>0){
+			/* there are set file descriptors, return immediately */
+			//printf("There are %i sessions set, returning.\n",ret);
+			rtp_scheduler_unlock(sched);
+			return ret;
+		}
+		//printf("There are %i sessions set.\n",ret);
+		/* else we wait until the next loop of the scheduler*/
+		ortp_cond_wait(&sched->unblock_select_cond,&sched->lock);
+		remainingTime -= sched->timer_inc;
+	} while (remainingTime>0);
+
+	return -1;
+}
